# YAMDOG <!-- omit in toc -->

Yet Another Markdown Only Generator

## Examples

> |  a  |          b          |                       $\leq$                      |
> |  :-- |  :-----------------: | ------------------------------------------------: |
> |  1  |          2          | [$\leq$](https://www.snakemd.io/en/latest/usage/) |
> |  3  | [Markdown Guide][1] |                         5                         |
> |  7  |   [hobbit-hole][2]  |                         9                         |

- Just text
- Sublist
    - a
    - b
- > |  a  |          b          |                       $\leq$                      |
  > |  :-- |  :-----------------: | ------------------------------------------------: |
  > |  1  |          2          | [$\leq$](https://www.snakemd.io/en/latest/usage/) |
  > |  3  | [Markdown Guide][1] |                         5                         |
  > |  7  |   [hobbit-hole][2]  |                         9                         |
- second sublisting, definition
    : First definition
    : Second definition
- [hobbit-hole][2]

[1]: <https://www.markdownguide.org> "Guide for Markdown"
[2]: <https://en.wikipedia.org/wiki/Hobbit#Lifestyle> "Hobbit lifestyles"
